@@ -8,10 +8,8 @@
 package Crypt::DES;
 
 require Exporter;
-require DynaLoader;
-use vars qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
 
-@ISA = qw(Exporter DynaLoader);
+@ISA = (Exporter, DynaLoader);
 
 # Items to export into callers namespace by default
 @EXPORT =	qw();
@@ -19,12 +17,14 @@ use vars qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
 # Other items we are prepared to export if requested
 @EXPORT_OK =	qw();
 
-$VERSION = '2.05_002';
-$XS_VERSION = $VERSION;
-bootstrap Crypt::DES $XS_VERSION;
+$VERSION = '2.01';
+bootstrap Crypt::DES;
+
+package DES;
 
 use strict;
 use Carp;
+use constant BLKSIZE => 8;
 
 sub usage
 {
@@ -34,8 +34,8 @@ sub usage
 }
 
 
-sub blocksize { 8; }
-sub keysize   { 8; }
+sub blocksize { BLKSIZE; }
+sub keysize { BLKSIZE; }
 
 sub new
 {
@@ -81,7 +81,7 @@ Crypt::DES - Perl DES encryption module
 
 =head1 DESCRIPTION
 
-The module implements the Crypt::CBC interface,
+The module implements the Crypt::BlockCipher interface,
 which has the following methods
 
 =over 4
@@ -144,9 +144,9 @@ blocks.  If you're intending to encrypt larger blocks or entire files,
 please use Crypt::CBC in conjunction with this module.  See the
 Crypt::CBC documentation for proper syntax and use.
 
-Also note that the DES algorithm is, by today's standard, weak 
+Also note that the DES algorithm is, by todays standard, weak 
 encryption.  Crypt::Blowfish is highly recommended if you're
-interested in using strong encryption and a faster algorithm. 
+interested in using strong encryption.
 
 =head1 SEE ALSO
 
